pub trait ArbitraryDelayActionExt: ArbitraryDelayAction {
// Provided method
fn schedule_with_arbitrary_delay<Fut, S, D>(
self,
is_shutdown: Fut,
spawn: &S,
make_delay: D,
initial_delay: Option<Duration>,
)
where Self: Sized,
Fut: Future<Output = ()> + Send + 'static,
S: Spawn,
D: MakeDelay + Send + 'static { ... }
}Expand description
An extension trait for ArbitraryDelayAction that provides scheduling methods.
Provided Methods
Sourcefn schedule_with_arbitrary_delay<Fut, S, D>(
self,
is_shutdown: Fut,
spawn: &S,
make_delay: D,
initial_delay: Option<Duration>,
)
fn schedule_with_arbitrary_delay<Fut, S, D>( self, is_shutdown: Fut, spawn: &S, make_delay: D, initial_delay: Option<Duration>, )
Creates and executes a repeatable action that becomes enabled first after the given
initial_delay, and subsequently based on the result of the action.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.